# LogicBook
Logicbook is an open source tool for building python logics in isolation. It streamlines logic development, testing, and documentation.

More document is [here](https://ruihirano.github.io/logicbook/).

<img width="1000" alt="example" src="https://user-images.githubusercontent.com/43264434/159141578-87f87ab0-502a-4fa6-a875-1197762202c3.png">

## Getting Started

Get started by **creating a new logicbook**.

### What you'll need

- [Python 3](https://www.python.org/downloads/) 
- Pip

## Generate a new logicbook site

Generate a new Logicbook site using the **logicbook command**.

```bash
cd your-python-project
logicbook init
```

You can type this command into Command Prompt, Powershell, Terminal, or any other integrated terminal of your code editor.

The command also installs all necessary dependencies you need to run Logicbook.

## Start your logicbook

Run the development server:

```bash
cd your-python-project
logicbook start
```

The `logicbook start` command builds your logicbook locally and serves it through a development server, ready for you to view at http://localhost:8000/.
